@@ -3,8 +3,9 @@ __doc__  = """pyspark_ds_toobox
 A Pyspark companion for data science tasks.
 """
 
-__version__ = '0.1.0'
+#__version__ = '0.1.0'
 
 from pyspark_ds_toolbox import wrangling
 from pyspark_ds_toolbox import ml
 from pyspark_ds_toolbox import causal_inference
+from pyspark_ds_toolbox import stats
\ No newline at end of file
